yakumo.neutron.v2.metering.rule

Package yakumo :: Package neutron :: Package v2 :: Package metering :: Module rule |
[hide private]
[frames] | no frames]

# Module rule

source code

Resource class and its manager for metering label rules for Networking v2 API

Classes | [hide private]
| Resource Resource class for metering label rules for Networking v2 API
| Manager Manager class for metering label rules for Networking v2 API

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass obj`...``
| __package__ = ``'``yakumo.neutron.v2.metering``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('id', 'id', mapper.Noop), ('remote_ip_prefix', 'remote_ip_prefix', m
      apper.Noop), ('direction', 'direction', mapper.Noop), ('excluded', 'ex
      cluded', mapper.Noop), ('metering_label', 'metering_label_id', mapper.
      Resource('neutron.metering.label')),]